from rest_framework import serializers


class XyGraphSerializer(serializers.Serializer):
    x_value = serializers.FloatField()
    y_value = serializers.FloatField()


class CheckGpuSerializer(serializers.Serializer):
    utilz_gpu = serializers.IntegerField()
    hms_time = serializers.CharField()



import argparse
import os
import sys

from django.core.management import execute_from_command_line


def main() -> None:
    parser = argparse.ArgumentParser(description="Launch Visualization Tool")
    parser.add_argument("--port", type=int, default=8000, help="number of port")
    parser.add_argument("--logpath", type=str, help="path to log file")
    args = parser.parse_args()

    project_root = os.path.abspath(os.path.join(os.path.dirname(__file__)))
    sys.path.append(project_root)

    if args.logpath:
        os.environ["LOG_PATH"] = args.logpath
        if not os.path.isfile(args.logpath):
            print(f"Not found file: {args.logpath}")
            sys.exit(1)
    else:
        print(
            "Error: The '--logpath' argument is required. Please specify the log file path. Example usage: qdvis --logpath /path/to/logfile"
        )
        sys.exit(1)

    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "config.settings")
    execute_from_command_line([sys.argv[0], "runserver", str(args.port)])


if __name__ == "__main__":
    main()



import json
import os
import subprocess
from datetime import datetime
from functools import wraps
from typing import Union


def subprocess_error_handler(func):  # type: ignore
    @wraps(func)
    def wrapper(*args, **kwargs):  # type: ignore
        try:
            func(*args, **kwargs)
        except subprocess.CalledProcessError as e:
            print(f"Error occurred while executing command: [{e}]")

        except FileNotFoundError as e:
            print(f"Command not found: {e}")

        except Exception as e:
            print(f"An unexpected error occurred: {e}")
        return None

    return wrapper


def get_now_time_hms() -> str:
    current = datetime.now()
    hms_time = current.strftime("%H:%M:%S")
    return hms_time


class LogWriter:
    def __init__(self, log_dir: str = "logs") -> None:
        self.log_dir = log_dir
        if not os.path.exists(log_dir):
            os.mkdir(log_dir)
        self.log_file = os.path.join(
            log_dir, f"log_{datetime.now().strftime('%Y%m%d_%H%M%S')}.json"
        )

    def add_scalar(
        self, x_value: Union[int, float], y_value: Union[int, float]
    ) -> None:
        data = {"tag": "xy", "x_value": x_value, "y_value": y_value}
        with open(self.log_file, "a") as f:
            f.write(json.dumps(data) + "\n")

    @subprocess_error_handler
    def add_gpu_status(self) -> None:
        query = "utilization.gpu"
        output_fmt = "csv,nounits,noheader"
        cmd = f"nvidia-smi --query-gpu={query} --format={output_fmt}"
        result = subprocess.run(
            cmd.split(), stdout=subprocess.PIPE, stderr=subprocess.PIPE, check=True
        )
        gpu_utilization = int(result.stdout.decode("utf-8").strip())
        hms_time = get_now_time_hms()
        data = {"tag": "gpu", "utilz_gpu": gpu_utilization, "hms_time": hms_time}
        with open(self.log_file, "a") as f:
            f.write(json.dumps(data) + "\n")



import json
import os
from typing import Any, Dict, List

from django.http import HttpResponse
from django.shortcuts import render
from rest_framework import status
from rest_framework.request import Request
from rest_framework.response import Response
from rest_framework.views import APIView

from .serializers import CheckGpuSerializer, XyGraphSerializer

# Create your views here.


class SampleAPIView(APIView):
    def get(self, request: Request) -> Response:
        return Response("OK !!", status=status.HTTP_200_OK)


def parse_json_log(logpath: str, req_type: str) -> List[Dict[str, Any]]:
    ps_log: List[Dict[str, Any]] = []
    with open(logpath, "r") as file:
        for line in file:
            log_entry = json.loads(line)
            if log_entry["tag"] == req_type:
                ps_log.append(log_entry)

    return ps_log


class XyGraphAPIView(APIView):
    def get(self, request: Request) -> Response:
        logpath = os.environ.get("LOG_PATH")
        if logpath is None:
            return Response(
                data={"error": "LOG_PATH environment variable not set"},
                status=status.HTTP_400_BAD_REQUEST,
            )
        ps_log = parse_json_log(logpath, req_type="xy")

        serializer = XyGraphSerializer(data=ps_log, many=True)
        serializer.is_valid(raise_exception=True)

        return Response(serializer.data)


class CheckGpuAPIView(APIView):
    def get(self, request: Request) -> Response:
        logpath = os.environ.get("LOG_PATH")
        if logpath is None:
            return Response(
                data={"error": "LOG_PATH environment variable not set"},
                status=status.HTTP_400_BAD_REQUEST,
            )
        ps_log = parse_json_log(logpath, req_type="gpu")

        serializer = CheckGpuSerializer(data=ps_log, many=True)
        serializer.is_valid(raise_exception=True)

        return Response(serializer.data)


# views.py
def index(request: Request) -> HttpResponse:
    return render(request, "index.html")



from api.views import CheckGpuAPIView, SampleAPIView, XyGraphAPIView
from django.urls import path

urlpatterns = [
    path("sample/", SampleAPIView.as_view(), name="sample"),
    path("xy_graph/", XyGraphAPIView.as_view()),
    path("gpu/", CheckGpuAPIView.as_view()),
]



"""
ASGI config for backend project.

It exposes the ASGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/4.2/howto/deployment/asgi/
"""

import os

from channels.auth import AuthMiddlewareStack
from channels.routing import ProtocolTypeRouter, URLRouter
from django.core.asgi import get_asgi_application

import qdvis.backend.backend.routing

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "backend.settings")

application = ProtocolTypeRouter(
    {
        "http": get_asgi_application(),
        "websocket": AuthMiddlewareStack(
            URLRouter(qdvis.backend.backend.routing.websocket_urlpatterns)
        ),
    }
)



from setuptools import find_packages, setup


def requirements_from_file(file_name):
    return open(file_name).read().splitlines()

with open('README.md', 'r', encoding='utf-8') as fp:
    readme = fp.read()
LONG_DESCRIPTION = readme

setup(
    name="qdvis",
    description="qdvis: Quick data visualizer.",
    author="Takeguchi",
    author_email="hirotake.stu@gmail.com",
    maintainer="Takeguchi",
    maintainer_email="hirotake.stu@gmail.com",
    url="https://github.com/ta-ke-inf/qdvis/tree/main",
    download_url="https://github.com/ta-ke-inf/qdvis/tree/main",
    license="MIT",
    version="0.1.2",
    keywords="visualization ml",
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    include_package_data=True,
    install_requires=requirements_from_file("requirements.txt"),
    entry_points={"console_scripts": ["qdvis=qdvis.cli:main"]},
)
